@@ -2,10 +2,6 @@ class ApiGatewayException(Exception):
     """Base Api Gateway Exception."""
 
 
-class InvalidAuthenticationException(ApiGatewayException):
-    """Exception to be raised when authentication is not valid."""
-
-
 class NoTokenException(ApiGatewayException):
     """Exception to be raised when token is not available."""
 
